@@ -423,8 +423,8 @@ help_contents (GtkAction *action,
       continue;
     }
  
-    uri = g_build_filename (DATADIR,
-                            "gnome", "help", "gucharmap",
+    uri = g_build_filename (HELPDIR,
+                            "gucharmap", /* DOC_MODULE */
                             lang,
                             "gucharmap.xml",
                             NULL);
@@ -454,6 +454,21 @@ about_open_url (GtkAboutDialog *about,
   open_url (GTK_WINDOW (about), link, gtk_get_current_event_time ());
 }
 
+static void
+about_email_hook (GtkAboutDialog *about,
+		  const char *email_address,
+		  gpointer user_data)
+{
+  char *escaped, *uri;
+
+  escaped = g_uri_escape_string (email_address, NULL, FALSE);
+  uri = g_strdup_printf ("mailto:%s", escaped);
+  g_free (escaped);
+
+  open_url (GTK_WINDOW (about), uri, gtk_get_current_event_time ());
+  g_free (uri);
+}
+
 static void
 help_about (GtkAction       *action, 
             GucharmapWindow *guw)
@@ -500,22 +515,22 @@ help_about (GtkAction       *action,
 			       _(license[4]), "\n\n", NULL);
 
   gtk_about_dialog_set_url_hook (about_open_url, NULL, NULL);
+  gtk_about_dialog_set_email_hook (about_email_hook, NULL, NULL);
 
   gtk_show_about_dialog (GTK_WINDOW (guw),
-  			 "authors", authors,
-			 "comments", _("GNOME Character Map "
-				       "based on the Unicode Character Database"),
+			 "program-name", _("GNOME Character Map"),
+			 "version", VERSION,
+			 "comments", _("Based on the Unicode Character Database 5.2"),
 			 "copyright", "Copyright © 2004 Noah Levitt\n"
-				      "Copyright © 1991-2008 Unicode, Inc.\n"
-				      "Copyright © 2007, 2008 Christian Persch",
+				      "Copyright © 1991–2009 Unicode, Inc.\n"
+				      "Copyright © 2007–2010 Christian Persch",
 			 "documenters", documenters,
 			 "license", license_trans,
-			 "program-name", _("Gucharmap"),
-			 "logo-icon-name", GUCHARMAP_ICON_NAME,
-			 "translator-credits", _("translator-credits"),
-			 "version", VERSION,
-			 "website", "http://live.gnome.org/Gucharmap",
 			 "wrap-license", TRUE,
+			 "logo-icon-name", GUCHARMAP_ICON_NAME,
+  			 "authors", authors,
+			 "translator-credits", _("translator-credits"),
+			 "website", "http://live.gnome.org/Gucharmap",
 			 NULL);
 
   g_free (license_trans);
@@ -847,9 +862,9 @@ gucharmap_window_init (GucharmapWindow *guw)
 
     { "Find", GTK_STOCK_FIND, NULL, NULL,
       NULL, G_CALLBACK (search_find) },
-    { "FindNext", GTK_STOCK_FIND, N_("Find _Next"), "<control>G",
+    { "FindNext", NULL, N_("Find _Next"), "<control>G",
       NULL, G_CALLBACK (search_find_next) },
-    { "FindPrevious", GTK_STOCK_FIND, N_("Find _Previous"), "<shift><control>G",
+    { "FindPrevious", NULL, N_("Find _Previous"), "<shift><control>G",
       NULL, G_CALLBACK (search_find_prev) },
 
     { "NextCharacter", NULL, N_("_Next Character"), "<control>N",
